%define anolis_release 3

%undefine __cmake_in_source_build

Summary:    Library to make writing a VNC server easy
Name:       libvncserver
Version:    0.9.13
Release:    %{anolis_release}%{?dist}

# NOTE: --with-filetransfer => GPLv2
License:    GPLv2+
URL:        http://libvnc.github.io/
Source0:    https://github.com/LibVNC/libvncserver/archive/LibVNCServer-%{version}.tar.gz

## TLS security type enablement patches
# https://github.com/LibVNC/libvncserver/pull/234
Patch10: 0001-libvncserver-Add-API-to-add-custom-I-O-entry-points.patch
Patch11: 0002-libvncserver-Add-channel-security-handlers.patch
# https://github.com/LibVNC/libvncserver/commit/87c52ee0551b7c4e76855d270d475b9e3039fe08
Patch12: 0003-libvncserver-auth-don-t-keep-security-handlers-from-.patch
# Fix crash on all runs after the first
# https://github.com/LibVNC/libvncserver/pull/444
Patch13: 0004-zlib-Clear-buffer-pointers-on-cleanup-444.patch
# Fix another crasher
# https://gitlab.gnome.org/GNOME/gnome-remote-desktop/-/issues/45
Patch14: 0001-libvncserver-don-t-NULL-out-internal-of-the-default-.patch

## downstream patches
Patch102: libvncserver-LibVNCServer-0.9.13-system-crypto-policy.patch

Patch103: 0005-libvncserver-CVE-2020-29260.patch

BuildRequires:  gcc-c++
BuildRequires:  cmake3
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
#BuildRequires:  pkgconfig(lzo2)
#BuildRequires:  ffmpeg-devel
BuildRequires:  gettext-devel
BuildRequires:  libgcrypt-devel


BuildRequires:  lzo-devel
BuildRequires:  lzo-minilzo
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)

# For %%check
BuildRequires:  xorg-x11-xauth
BuildRequires:  zlib-devel

%description
LibVNCServer makes writing a VNC server (or more correctly, a program exporting
a frame-buffer via the Remote Frame Buffer protocol) easy.

It hides the programmer from the tedious task of managing clients and
compression schemata.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:    Development files for %{name}
Requires:   %{name} = %{version}-%{release}
# libvncserver-config deps
Requires:   coreutils
# /usr/include/rfb/rfbproto.h:#include <zlib.h>
Requires:   zlib-devel

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -p1 -n %{name}-LibVNCServer-%{version}

# Nuke bundled minilzo
rm -fv common/lzodefs.h common/lzoconf.h commmon/minilzo.h common/minilzo.c


# Fix encoding
for file in ChangeLog ; do
    mv ${file} ${file}.OLD && \
    iconv -f ISO_8859-1 -t UTF8 ${file}.OLD > ${file} && \
    touch --reference ${file}.OLD $file
done


%build
%cmake3

%cmake_build


%install
%cmake_install

%ldconfig_scriptlets

%generate_compatibility_deps

%files
%license COPYING
%{_libdir}/libvncclient.so.1
%{_libdir}/libvncclient.so.%{version}
%{_libdir}/libvncserver.so.1
%{_libdir}/libvncserver.so.%{version}
%dir %{abidir}
%{abidir}/libvncclient.dump
%{abidir}/libvncserver.dump

%files doc
%doc AUTHORS ChangeLog NEWS* README* TODO* 

%files devel
#{_bindir}/libvncserver-config
%{_includedir}/rfb/
%{_libdir}/libvncclient.so
%{_libdir}/libvncserver.so
%{_libdir}/pkgconfig/libvncclient.pc
%{_libdir}/pkgconfig/libvncserver.pc


%changelog
* Mon Dec 09 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.13-3
- Rebuild for remove inappropriate build dependencies.

* Thu Nov 09 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.13-2
- fix CVE-2020-29260

* Tue Apr 11 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.13-1
- Init upstream from version 0.9.13
